pari_seadata: PARI data package needed by ellap for large primes (full version)
===============================================================================

Description
-----------

Needed by ellap for large primes. These polynomials were extracted from
the ECHIDNA databases and computed by David R. Kohel. This covers finite
fields of cardinality q up to 750 bits. PARI/GP 2.9 contains fallback
code to go on when all modular polynomials in the database have been
exhausted and can handle larger fields (with an important slowdown).

License
-------

GNU General Public License (GPL version 2 or any later version).


Upstream Contact
----------------

http://pari.math.u-bordeaux.fr/
